ultrayolo package
=================

Subpackages
-----------

.. toctree::

    ultrayolo.datasets
    ultrayolo.helpers
    ultrayolo.layers

Submodules
----------

ultrayolo.cli module
--------------------

.. automodule:: ultrayolo.cli
    :members:
    :undoc-members:
    :show-inheritance:

ultrayolo.learningrates module
------------------------------

.. automodule:: ultrayolo.learningrates
    :members:
    :undoc-members:
    :show-inheritance:

ultrayolo.losses module
-----------------------

.. automodule:: ultrayolo.losses
    :members:
    :undoc-members:
    :show-inheritance:

ultrayolo.ultrayolo module
--------------------------

.. automodule:: ultrayolo.ultrayolo
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ultrayolo
    :members:
    :undoc-members:
    :show-inheritance:
